==> owncloud-10.2.0.zip: owncloud/apps/files/l10n/ru.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Хранилище временно не доступно",
    "Storage invalid" : "Хранилище неисправно",
    "Unknown error" : "Неизвестная ошибка",
    "All files" : "Все файлы",
    "Saved" : "Сохранено",
    "There was an error saving" : "Была ошибка при сохранении",
    "File could not be found" : "Файл не может быть найден",
    "Home" : "Главная",
    "Close" : "Закрыть",
    "Favorites" : "Избранное",
    "Could not create folder \"{dir}\"" : "Невозможно создать папку \"{dir}\"",
    "Upload cancelled." : "Загрузка отменена.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Невозможно загрузить {filename}, так как это либо каталог, либо файл нулевого размера",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Недостаточно свободного места, Вы загружаете {size1}, но осталось только {size2}",
    "Target folder \"{dir}\" does not exist any more" : "Целевой каталог \"{dir}\" больше не существует",
    "Target folder does not exist any more" : "Целевой каталог уже не существует",
    "Not enough free space" : "Не хватает свободного места",
    "Uploading..." : "Загрузка...",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} из {totalSize} ({bitrate})",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Идёт загрузка файла. Покинув страницу, вы прервёте загрузку.",
    "Actions" : "Действия",
    "Download" : "Скачать",
    "Rename" : "Переименовать",
    "Delete" : "Удалить",
    "Disconnect storage" : "Отсоединить хранилище",
    "Unshare" : "Закрыть доступ",
    "Could not load info for file \"{file}\"" : "Не удалось загрузить информацию для файла \"{file}\"",
    "Files" : "Файлы",
    "Details" : "Подробно",
    "Select" : "Выбрать",
    "Pending" : "Ожидается",
    "Unable to determine date" : "Невозможно определить дату",
    "Invalid path" : "Некорректный путь",
    "This operation is forbidden" : "Операция запрещена",
    "This directory is unavailable, please check the logs or contact the administrator" : "Директория недоступна, пожалуйста проверьте журнал сообщений или свяжитесь с администратором",
    "Could not move \"{file}\", target exists" : "Невозможно переместить \"{file}\", цель отсутствует",
    "Could not move \"{file}\"" : "Невозможно переместить \"{file}\"",
    "{newName} already exists" : "{newName} уже имеется",
    "Could not rename \"{fileName}\", it does not exist any more" : "Невозможно переименовать \"{fileName}\", файл больше не существует",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Имя \"{targetName}\" уже используется в каталоге \"{dir}\". Пожалуйста, выберите другое имя.",
    "Could not rename \"{fileName}\"" : "Невозможно переименовать \"{fileName}\"",
    "Could not create file \"{file}\"" : "Невозможно создать файл \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Невозможно создать файл \"{file}\" потому что уже имеется",
    "Could not create folder \"{dir}\" because it already exists" : "Невозможно создать папку \"{dir}\" потому что уже имеется",
    "Error deleting file \"{fileName}\"." : "Ошибка удаления файла \"{fileName}\".",
    "No entries in this folder match {filter}" : "Никаие элементы в этом каталоге не соответствуют {filter}",
    "Name" : "Имя",
    "Size" : "Размер",
    "Modified" : "Изменён",
    "_%n folder_::_%n folders_" : ["%n каталог","%n каталога","%n каталогов","%n каталогов"],
    "_%n file_::_%n files_" : ["%n файл","%n файла","%n файлов","%n файлов"],
    "{dirs} and {files}" : "{dirs} и {files}",
    "_including %n hidden_::_including %n hidden_" : ["включая %n скрытый","включая %n скрытых","включая %n скрытых","включая %n скрытых"],
    "You don’t have permission to upload or create files here" : "У вас нет прав для загрузки или создания файлов здесь.",
    "_Uploading %n file_::_Uploading %n files_" : ["Закачка %n файла","Закачка %n файлов","Закачка %n файлов","Закачка %n файлов"],
    "New" : "Новый",
    "\"{name}\" is an invalid file name." : "\"{name}\" это неправильное имя файла.",
    "File name cannot be empty." : "Имя файла не может быть пустым.",
    "\"{name}\" has a forbidden file type/extension." : "У «{name}» запрещённый тип/расширение файла.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Хранилище {owner} переполнено, файлы больше не могут быть обновлены или синхронизированы!",
    "Your storage is full, files can not be updated or synced anymore!" : "Ваше хранилище заполнено, произведите очистку перед загрузкой новых файлов.",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Хранилище {owner} практически заполнено ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Ваше хранилище почти заполнено ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["соответствует '{filter}'","соответствуют '{filter}'","соответствуют '{filter}'","соответствуют '{filter}'"],
    "Path" : "Путь",
    "_%n byte_::_%n bytes_" : ["%n байт","%n байта","%n байтов","%n байта(ов)"],
    "Favorited" : "Избранное",
    "Favorite" : "Избранное",
    "Private link:  Only people who have access to the file/folder can use it. Use it as a permanent link for yourself or to point others to files within shares" : "Персональная ссылка: Только тот, кто имеет доступ к файлу/папке может её использовать. Используйте её, как свою постоянную ссылку или для указания другим файлов в папках общего доступа.",
    "Folder" : "Каталог",
    "New folder" : "Новый каталог",
    "{newname} already exists" : "{newname} уже существует",
    "Upload" : "Загрузить",
    "An error occurred while trying to update the tags" : "Во время обновления тегов возникла ошибка",
    "A new file or folder has been <strong>created</strong>" : "<strong>Создан</strong> новый файл или каталог",
    "A file or folder has been <strong>changed</strong>" : "<strong>Изменён</strong> файл или каталог",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Ограничить уведомления о создании и изменении ваших <strong>избранных файлов</strong> <em>(отображать только в приложении события)</em>",
    "A file or folder has been <strong>deleted</strong>" : "<strong>Удален</strong> файл или каталог",
    "A file or folder has been <strong>restored</strong>" : "<strong>Восстановлен</strong> файл или каталог",
    "You created %1$s" : "Вы создали %1$s",
    "%2$s created %1$s" : "%2$s создал %1$s",
    "%1$s was created in a public folder" : "%1$s создан в общем каталоге",
    "You changed %1$s" : "Вы изменили %1$s",
    "%2$s changed %1$s" : "%2$s изменил %1$s",
    "You deleted %1$s" : "Вы удалили %1$s",
    "%2$s deleted %1$s" : "%2$s удалил %1$s",
    "You restored %1$s" : "Вы восстановили %1$s",
    "%2$s restored %1$s" : "%2$s восстановил %1$s",
    "Changed by %2$s" : "Изменено %2$s",
    "Deleted by %2$s" : "Удалено %2$s",
    "Restored by %2$s" : "Восстановлено %2$s",
    "Upload (max. %s)" : "Загрузка (максимум %s)",
    "File handling" : "Управление файлами",
    "Maximum upload size" : "Максимальный размер загружаемого файла",
    "max. possible: " : "макс. возможно: ",
    "Save" : "Сохранить",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "В режиме PHP-FPM применение изменений может занять до 5 минут.",
    "Missing permissions to edit from here." : "Отсутствуют права на удаление.",
    "Settings" : "Настройки",
    "Show hidden files" : "Показать скрытые файлы",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Используйте этот адрес для <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">для доступа к вашим файлам по WebDAV</a>",
    "No files in here" : "Здесь нет файлов",
    "Upload some content or sync with your devices!" : "Загрузите что-нибудь или синхронизируйте со своими устройствами!",
    "No entries found in this folder" : "Ничего не найдено",
    "Select all" : "Выбрать все",
    "Upload too large" : "Файл слишком велик",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Файлы, которые вы пытаетесь загрузить, превышают лимит максимального размера на этом сервере.",
    "No favorites" : "Нет избранного",
    "Files and folders you mark as favorite will show up here" : "Здесь появятся файлы и каталоги, отмеченные как избранные",
    "Text file" : "Текстовый файл",
    "New text file.txt" : "Новый текстовый документ.txt",
    "Upload timeout for file \"{file}\"" : "Тайм-аут для загрузки файла \"{file}\"",
    "Processing files..." : "Обработка файлов...",
    "Limit notifications about creation and changes to your <strong>favorite files</strong>" : "Ограничить уведомления о создании и изменений только вашими <strong>избранными файлами</strong>",
    "You don't have permissions to access this file/folder - Please contact the owner to share it with you." : "У вас нет разрешения на доступ к этому файлу или папке. Пожалуйста обратитесь к владельцу, чтобы он предоставил вам доступ.",
    "Error when assembling chunks, status code {status}" : "Ошибка при сборке блоков, код состояния {status}",
    "The file {file} is currently locked, please try again later" : "В настоящий момент файл {file} заблокирован, попробуйте ещё раз позже",
    "Lock status" : "Состояние блокировки",
    "This resource is locked. Click to see more details." : "Ресурс заблокирован. Нажмите, чтобы посмотреть подробности.",
    "{owner} has locked this resource via {path}" : "{owner} заблокировал(а) данный ресурс через {path}",
    "Could not unlock, please contact the lock owner {owner}" : "Не удалось разблокировать, пожалуйста свяжитесь с владельцем блокировки {owner}",
    "Unlock failed with status {status}" : "Разблокировать не удалось, статус {status}",
    "Locks" : "Блокировки",
    "Resource is not locked" : "Ресурс не заблокирован",
    "Unknown user" : "Неизвестный пользователь"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> owncloud-10.4.0.zip: owncloud/apps/files/l10n/ru.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Хранилище временно не доступно",
    "Storage invalid" : "Хранилище неисправно",
    "Unknown error" : "Неизвестная ошибка",
    "All files" : "Все файлы",
    "File could not be found" : "Файл не может быть найден",
    "Home" : "Главная",
    "Close" : "Закрыть",
    "Favorites" : "Избранное",
    "Upload timeout for file \"{file}\"" : "Тайм-аут для загрузки файла \"{file}\"",
    "Unknown error \"{error}\" uploading file \"{file}\"" : "Неизвестная ошибка \"{error}\" при загрузке файла \"{file}\"",
    "Could not create folder \"{dir}\"" : "Невозможно создать папку \"{dir}\"",
    "Upload cancelled." : "Загрузка отменена.",
    "The file {file} already exists" : "Файл {file} уже существует",
    "Processing files..." : "Обработка файлов...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Невозможно загрузить {filename}, так как это либо каталог, либо файл нулевого размера",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Недостаточно свободного места, Вы загружаете {size1}, но осталось только {size2}",
    "Target folder \"{dir}\" does not exist any more" : "Целевой каталог \"{dir}\" больше не существует",
    "Target folder does not exist any more" : "Целевой каталог уже не существует",
    "The file {file} is currently locked, please try again later" : "В настоящий момент файл {file} заблокирован, попробуйте ещё раз позже",
    "Not enough free space" : "Не хватает свободного места",
    "Uploading..." : "Загрузка...",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} из {totalSize} ({bitrate})",
    "Error when assembling chunks, status code {status}" : "Ошибка при сборке блоков, код состояния {status}",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Идёт загрузка файла. Покинув страницу, вы прервёте загрузку.",
    "Actions" : "Действия",
    "Download" : "Скачать",
    "Rename" : "Переименовать",
    "Delete" : "Удалить",
    "Disconnect storage" : "Отсоединить хранилище",
    "Unshare" : "Закрыть доступ",
    "Could not load info for file \"{file}\"" : "Не удалось загрузить информацию для файла \"{file}\"",
    "Files" : "Файлы",
    "Details" : "Подробно",
    "Select" : "Выбрать",
    "Pending" : "Ожидается",
    "Unable to determine date" : "Невозможно определить дату",
    "Invalid path" : "Некорректный путь",
    "This operation is forbidden" : "Операция запрещена",
    "This directory is unavailable, please check the logs or contact the administrator" : "Директория недоступна, пожалуйста проверьте журнал сообщений или свяжитесь с администратором",
    "group" : "группа",
    "Remote share" : "Удаленный общий ресурс",
    "via" : "через",
    "Could not move \"{file}\", target exists" : "Невозможно переместить \"{file}\", цель отсутствует",
    "Could not move \"{file}\" because either the file or the target are locked." : "Не удалось переместить \"{file}\" так как или файл, или место назначения заблокированы.",
    "Could not move \"{file}\": {message}" : "Не удалось переместить \"{file}\": {message}",
    "Could not move \"{file}\"" : "Невозможно переместить \"{file}\"",
    "{newName} already exists" : "{newName} уже имеется",
    "Could not rename \"{fileName}\", it does not exist any more" : "Невозможно переименовать \"{fileName}\", файл больше не существует",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Имя \"{targetName}\" уже используется в каталоге \"{dir}\". Пожалуйста, выберите другое имя.",
    "The file \"{fileName}\" is locked and can not be renamed." : "Файл \"{fileName}\" заблокирован, его невозможно переименовать.",
    "Could not rename \"{fileName}\"" : "Невозможно переименовать \"{fileName}\"",
    "Could not create file \"{file}\"" : "Невозможно создать файл \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Невозможно создать файл \"{file}\" потому что уже имеется",
    "Could not create folder \"{dir}\" because it already exists" : "Невозможно создать папку \"{dir}\" потому что уже имеется",
    "The file \"{fileName}\" is locked and cannot be deleted." : "Файл \"{fileName}\" заблокирован, его невозможно удалить.",
    "Error deleting file \"{fileName}\"." : "Ошибка удаления файла \"{fileName}\".",
    "No entries in this folder match {filter}" : "Никаие элементы в этом каталоге не соответствуют {filter}",
    "Name" : "Имя",
    "Size" : "Размер",
    "Modified" : "Изменён",
    "_%n folder_::_%n folders_" : ["%n каталог","%n каталога","%n каталогов","%n каталогов"],
    "_%n file_::_%n files_" : ["%n файл","%n файла","%n файлов","%n файлов"],
    "{dirs} and {files}" : "{dirs} и {files}",
    "_including %n hidden_::_including %n hidden_" : ["включая %n скрытый","включая %n скрытых","включая %n скрытых","включая %n скрытых"],
    "You don’t have permission to upload or create files here" : "У вас нет прав для загрузки или создания файлов здесь.",
    "_Uploading %n file_::_Uploading %n files_" : ["Закачка %n файла","Закачка %n файлов","Закачка %n файлов","Закачка %n файлов"],
    "New" : "Новый",
    "Unknown user" : "Неизвестный пользователь",
    "Lock status" : "Состояние блокировки",
    "This resource is locked. Click to see more details." : "Ресурс заблокирован. Нажмите, чтобы посмотреть подробности.",
    "\"{name}\" is an invalid file name." : "\"{name}\" это неправильное имя файла.",
    "File name cannot be empty." : "Имя файла не может быть пустым.",
    "File name cannot contain \"/\"." : "Имя файла не может содержать символ \"/\".",
    "\"{name}\" has a forbidden file type/extension." : "У «{name}» запрещённый тип/расширение файла.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Хранилище {owner} переполнено, файлы больше не могут быть обновлены или синхронизированы!",
    "Your storage is full, files can not be updated or synced anymore!" : "Ваше хранилище заполнено, произведите очистку перед загрузкой новых файлов.",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Хранилище {owner} практически заполнено ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Ваше хранилище почти заполнено ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["соответствует '{filter}'","соответствуют '{filter}'","соответствуют '{filter}'","соответствуют '{filter}'"],
    "{owner} has locked this resource via {path}" : "{owner} заблокировал(а) данный ресурс через {path}",
    "Could not unlock, please contact the lock owner {owner}" : "Не удалось разблокировать, пожалуйста свяжитесь с владельцем блокировки {owner}",
    "Unlock failed with status {status}" : "Разблокировать не удалось, статус {status}",
    "Locks" : "Блокировки",
    "Resource is not locked" : "Ресурс не заблокирован",
    "Path" : "Путь",
    "_%n byte_::_%n bytes_" : ["%n байт","%n байта","%n байтов","%n байта(ов)"],
    "Favorited" : "Избранное",
    "Favorite" : "Избранное",
    "Private link:  Only people who have access to the file/folder can use it. Use it as a permanent link for yourself or to point others to files within shares" : "Персональная ссылка: Только тот, кто имеет доступ к файлу/папке может её использовать. Используйте её, как свою постоянную ссылку или для указания другим файлов в папках общего доступа.",
    "Folder" : "Каталог",
    "New folder" : "Новый каталог",
    "{newname} already exists" : "{newname} уже существует",
    "Upload" : "Загрузить",
    "An error occurred while trying to update the tags" : "Во время обновления тегов возникла ошибка",
    "A new file or folder has been <strong>created</strong>" : "<strong>Создан</strong> новый файл или каталог",
    "A file or folder has been <strong>changed</strong>" : "<strong>Изменён</strong> файл или каталог",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Ограничить уведомления о создании и изменении ваших <strong>избранных файлов</strong> <em>(отображать только в приложении события)</em>",
    "A file or folder has been <strong>deleted</strong>" : "<strong>Удален</strong> файл или каталог",
    "A file or folder has been <strong>restored</strong>" : "<strong>Восстановлен</strong> файл или каталог",
    "You created %1$s" : "Вы создали %1$s",
    "%2$s created %1$s" : "%2$s создал %1$s",
    "%1$s was created in a public folder" : "%1$s создан в общем каталоге",
    "You changed %1$s" : "Вы изменили %1$s",
    "%2$s changed %1$s" : "%2$s изменил %1$s",
    "You deleted %1$s" : "Вы удалили %1$s",
    "%2$s deleted %1$s" : "%2$s удалил %1$s",
    "You restored %1$s" : "Вы восстановили %1$s",
    "%2$s restored %1$s" : "%2$s восстановил %1$s",
    "Changed by %2$s" : "Изменено %2$s",
    "Deleted by %2$s" : "Удалено %2$s",
    "Restored by %2$s" : "Восстановлено %2$s",
    "You don't have permissions to access this file/folder - Please contact the owner to share it with you." : "У вас нет разрешения на доступ к этому файлу или папке. Пожалуйста обратитесь к владельцу, чтобы он предоставил вам доступ.",
    "Upload (max. %s)" : "Загрузка (максимум %s)",
    "Settings" : "Настройки",
    "Show hidden files" : "Показать скрытые файлы",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Используйте этот адрес для <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">для доступа к вашим файлам по WebDAV</a>",
    "No files in here" : "Здесь нет файлов",
    "Upload some content or sync with your devices!" : "Загрузите что-нибудь или синхронизируйте со своими устройствами!",
    "No entries found in this folder" : "Ничего не найдено",
    "Select all" : "Выбрать все",
    "Upload too large" : "Файл слишком велик",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Файлы, которые вы пытаетесь загрузить, превышают лимит максимального размера на этом сервере.",
    "No favorites" : "Нет избранного",
    "Files and folders you mark as favorite will show up here" : "Здесь появятся файлы и каталоги, отмеченные как избранные",
    "Text file" : "Текстовый файл",
    "New text file.txt" : "Новый текстовый документ.txt"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
